To be able to merge a pull request, there are a few checks:
[ ] the `black` style should be enforced (make lint)
[ ] the docs should be regenerated (make docs)
[ ] the pull request should pass the tests (make test)
[ ] the examples should be generated (make examples)
